==> netbluemind4-4.1.56794.tar.gz: netbluemind4-4.1.56794/netbluemind/user/api/ChangePassword.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ChangePassword :
    def __init__( self):
        self.currentPassword = None
        self.newPassword = None
        pass

class __ChangePasswordSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ChangePassword()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        currentPasswordValue = value['currentPassword']
        instance.currentPassword = serder.STRING.parse(currentPasswordValue)
        newPasswordValue = value['newPassword']
        instance.newPassword = serder.STRING.parse(newPasswordValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        currentPasswordValue = value.currentPassword
        instance["currentPassword"] = serder.STRING.encode(currentPasswordValue)
        newPasswordValue = value.newPassword
        instance["newPassword"] = serder.STRING.encode(newPasswordValue)
        return instance

==> netbluemind5-5.0.7611.tar.gz: netbluemind5-5.0.7611/netbluemind/user/api/ChangePassword.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ChangePassword:
    def __init__(self):
        self.currentPassword = None
        self.newPassword = None
        pass


class __ChangePasswordSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ChangePassword()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        currentPasswordValue = value['currentPassword']
        instance.currentPassword = serder.STRING.parse(currentPasswordValue)
        newPasswordValue = value['newPassword']
        instance.newPassword = serder.STRING.parse(newPasswordValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        currentPasswordValue = value.currentPassword
        instance["currentPassword"] = serder.STRING.encode(
            currentPasswordValue)
        newPasswordValue = value.newPassword
        instance["newPassword"] = serder.STRING.encode(newPasswordValue)
        return instance
